from aiohttp import ClientSession, ClientConnectorError

BASE_URL = "https://datamall2.mytransport.sg/ltaodataservice/"

# Base async function to call api, receive response and handle errors.
async def call(api_key, url):
    async with ClientSession() as session:
        try:
            async with session.get(
                BASE_URL + url,
                headers={"Accept": "application/json", "AccountKey": api_key},
            ) as response:
                if response.status == 200:
                    return await response.json()
                else:
                    raise Exception(
                        "Received status code " + str(response.status)
                    ) from None
        except ClientConnectorError as err:
            raise Exception(str(err)) from None



from .api import call

# Retrieve images of live traffic along expressways and customs checkpoints.
async def get_traffic_images(api_key):
    data = await call(api_key, "Traffic-Imagesv2")
    return data["value"]


# Returns incidents currently happening.
async def get_traffic_incidents(api_key):
    data = await call(api_key, "TrafficIncidents")
    return data["value"]



from .api import call

# Retrieve data of all taxis only available for hire.
async def get_taxi_availability(api_key):
    data = await call(api_key, "Taxi-Availability")
    return data["value"]


# Retrieve data of all taxi stands.
async def get_taxi_stands(api_key):
    data = await call(api_key, "TaxiStands")
    return data["value"]



"""Exceptions for LTA Datamall API client"""


class LtapysgError(Exception):
    """General exception"""

    pass


class LtapysgConnectionError(LtapysgError):
    """Connection error occurs"""

    pass



from .api import call

# Retrieve arrival timings for all buses operating for specified bus stop. Each bus has 3 recurring timings.
async def get_bus_arrival(api_key, bus_stop_code):
    data = await call(api_key, "v3/BusArrival?BusStopCode=" + str(bus_stop_code))
    return data["Services"]


# Retrieve data of all operating bus services.
async def get_bus_services(api_key):
    data = await call(api_key, "BusServices")
    return data["value"]


# Retrieve data of all operating bus routes.
async def get_bus_routes(api_key):
    data = await call(api_key, "BusRoutes")
    return data["value"]


# Retrieve data of bus stops. Max number of records per page is 500.
async def get_bus_stops(api_key, page_no = 1):
    data = await call(api_key, "BusStops?page=" + str(page_no))
    return data["value"]
